==> lsof_4.28.orig.tar.gz: lsof-4.28.orig/dialects/n+obsd/dproto.h <==
/*
 * dproto.h - NetBSD and OpenBSD function prototypes for lsof
 *
 * The _PROTOTYPE macro is defined in the common proto.h.
 */


/*
 * Copyright 1994 Purdue Research Foundation, West Lafayette, Indiana
 * 47907.  All rights reserved.
 *
 * Written by Victor A. Abell
 *
 * This software is not subject to any license of the American Telephone
 * and Telegraph Company or the Regents of the University of California.
 *
 * Permission is granted to anyone to use this software for any purpose on
 * any computer system, and to alter it and redistribute it freely, subject
 * to the following restrictions:
 *
 * 1. Neither the authors nor Purdue University are responsible for any
 *    consequences of the use of this software.
 *
 * 2. The origin of this software must not be misrepresented, either by
 *    explicit claim or by omission.  Credit to the authors and Purdue
 *    University must appear in documentation and sources.
 *
 * 3. Altered versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 4. This notice may not be removed or altered.
 */


/*
 * $Id: dproto.h,v 1.5 98/03/06 08:24:47 abe Exp $
 */


_PROTOTYPE(extern int is_file_named,(char *p, enum vtype ty));
_PROTOTYPE(extern struct l_vfs *readvfs,(KA_T vm));

#if	defined(OPENBSDV)
_PROTOTYPE(extern void process_pipe,(KA_T pa));
#endif	/* defined(OPENBSDV) */

#if	defined(HAS9660FS)
_PROTOTYPE(extern int read_iso_node,(struct vnode *v, dev_t *d, unsigned long *ino, SZOFFTYPE *sz));
#endif	/* defined(HAS9660FS) */

_PROTOTYPE(extern void process_socket,(KA_T sa));

==> lsof-4.58.tar.gz: lsof_4.58/dialects/n+obsd/dproto.h <==
/*
 * dproto.h - NetBSD and OpenBSD function prototypes for lsof
 *
 * The _PROTOTYPE macro is defined in the common proto.h.
 */


/*
 * Copyright 1994 Purdue Research Foundation, West Lafayette, Indiana
 * 47907.  All rights reserved.
 *
 * Written by Victor A. Abell
 *
 * This software is not subject to any license of the American Telephone
 * and Telegraph Company or the Regents of the University of California.
 *
 * Permission is granted to anyone to use this software for any purpose on
 * any computer system, and to alter it and redistribute it freely, subject
 * to the following restrictions:
 *
 * 1. Neither the authors nor Purdue University are responsible for any
 *    consequences of the use of this software.
 *
 * 2. The origin of this software must not be misrepresented, either by
 *    explicit claim or by omission.  Credit to the authors and Purdue
 *    University must appear in documentation and sources.
 *
 * 3. Altered versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 4. This notice may not be removed or altered.
 */


/*
 * $Id: dproto.h,v 1.7 99/05/04 09:01:28 abe Exp $
 */


_PROTOTYPE(extern int is_file_named,(char *p, int cd));
_PROTOTYPE(extern struct l_vfs *readvfs,(KA_T vm));

#if	defined(OPENBSDV)
_PROTOTYPE(extern void process_pipe,(KA_T pa));
#endif	/* defined(OPENBSDV) */

#if	defined(HAS9660FS)
_PROTOTYPE(extern int read_iso_node,(struct vnode *v, dev_t *d, unsigned long *ino, long *nl, SZOFFTYPE *sz));
#endif	/* defined(HAS9660FS) */

_PROTOTYPE(extern void process_socket,(KA_T sa));
